--=============================
-- FILE LEVEL DETAIL
--=============================
DECLARE @start_date datetime

SELECT @start_date = create_date 
FROM sys.databases WHERE name = 'tempdb'

SELECT db_name(ioFS.database_id) as database_name
	, MF.name as file_name 
	, MF.physical_name
	, [ioFS].[num_of_reads] AS read_count
	, [ioFS].[num_of_bytes_read]/1024/1024 AS read_mb
	, CASE [ioFS].[num_of_reads]
		WHEN 0 THEN 0
		ELSE CAST([ioFS].[io_stall_read_ms]/([ioFS].[num_of_reads])/1.0 AS DECIMAL(10,1)) 
	END AS [avg_read_stall_ms]
	, [ioFS].[num_of_writes] AS write_count
	, [ioFS].[num_of_bytes_written]/1024/1024 AS write_mb
	, CASE [ioFS].[num_of_writes]
		WHEN 0 THEN 0
		ELSE CAST([ioFS].[io_stall_write_ms]/([ioFS].[num_of_writes])/1.0 AS DECIMAL(10,1))
	END AS [avg_write_stall_ms]
	, [ioFS].[size_on_disk_bytes]/1024 AS file_size_mb
	, [ioFS].[file_handle]
	, datediff(d, @start_date, getdate()) as days_sampled
	, getdate() as date_stamp
FROM sys.dm_io_virtual_file_stats(NULL,NULL) ioFS 
	INNER JOIN sys.master_files MF 
		ON ioFS.database_id = MF.database_id 
			AND ioFS.file_id = MF.file_id
ORDER BY 6 DESC;
GO


