--=============================================
-- SYS.DM_OS_PERFORMANCE_COUNTERS
--=============================================
SELECT DISTINCT [object_name]
	--, counter_name
	--, instance_name
      --, cntr_value
      --, cntr_type 
FROM sys.dm_os_performance_counters
ORDER BY [object_name]



SELECT DISTINCT [object_name], counter_name
	--, counter_name
	--, instance_name
      --, cntr_value
      --, cntr_type 
FROM sys.dm_os_performance_counters
ORDER BY [object_name], counter_name




SELECT DISTINCT --[object_name], counter_name,
	--, counter_name
	--, instance_name
      --, cntr_value
    cntr_type 
	, CASE cntr_type
		WHEN 65792 THEN 'PERF_COUNTER_LARGE_RAWCOUNT, a raw counter value for point in time.'
		WHEN 272696576 THEN 'PERF_COUNTER_BULK_COUNT; Average number of operations completed during each second of the sample interval.'
		WHEN 537003264 THEN 'PERF_AVERAGE_BULK; Number of average items processed during an operation.'
		WHEN 1073874176 THEN 'PERF_AVERAGE_BULK; Number of average items processed during an operation.'
		WHEN 1073939712 THEN 'PERF_LARGE_RAW_BASE; Base value for use in calculating a ratio.'
	END AS cntr_type_desc 
	, CASE cntr_type
		WHEN 65792 THEN 'Query & display.'
		WHEN 272696576 THEN 'Value is cumulative. Must calculate by taking the difference between any two successive sample values.'
		WHEN 537003264 THEN 'Since the counter type is a ratio of the items processed to the number of operations completed you must divide by a corresponding counter base value.'
		WHEN 1073874176 THEN 'Since the counter type is a ratio of the items processed to the number of operations completed you must divide by a corresponding counter base value.'
		WHEN 1073939712 THEN 'Use this counter as the corresponding base value for a ratio-based counter.'
	END AS calculation_method 
FROM sys.dm_os_performance_counters
WHERE [object_name] LIKE '%Buffer Manager%'
ORDER BY cntr_type;




--==============================================
-- EARLIER WE SAW THIS: BUFFER POOL SIZE
--==============================================
-- SQL 2012: (IF @@MICROSOFTVERSION / 0x01000000 = 11)
	SELECT committed_kb/1024 FROM sys.dm_os_sys_info AS buffer_pool_size_mb;
	SELECT committed_target_kb/1024 FROM sys.dm_os_sys_info AS buffer_pool_target_mb;



-- SQL OLDER:  IF @@MICROSOFTVERSION / 0x01000000 < 11
	SELECT bpool_committed/1024*8 FROM sys.dm_os_sys_info AS buffer_pool_size_mb;
	SELECT bpool_commit_target/1024*8 FROM sys.dm_os_sys_info AS buffer_pool_target_mb;





--==================================================
-- GET SAME INFO FROM SYS.DM_OS.PERFORMANCE_COUNTERS
--==================================================
SELECT cntr_value/1024 AS buffer_pool_size_mb 
FROM sys.dm_os_performance_counters 
WHERE counter_name = 'Total Server Memory (KB)';

SELECT cntr_value/1024 AS buffer_pool_target_mb 
FROM sys.dm_os_performance_counters 
WHERE counter_name = 'Target Server Memory (KB)';






--==============================================
-- COLLECT PERFORMANCE STATS W/O PERFMON
--==============================================
IF NOT EXISTS (SELECT name FROM tempdb.sys.tables WHERE name LIKE '%#dm_os_performance_counters%')
	BEGIN
		CREATE TABLE #dm_os_performance_counters
			(
				[object_name] [nvarchar](128) NULL,
				[counter_name] [nvarchar](128) NULL,
				[instance_name] [nvarchar](128) NULL,
				[cntr_value] [bigint] NULL,
				[date_stamp] [datetime] NULL
			) 
	END
 GO
 
   
-------------------------------------------
DECLARE @getdate DATETIME;

SELECT @getdate = GETDATE();

INSERT INTO #dm_os_performance_counters
        (object_name
       , counter_name
       , instance_name
       , cntr_value
       , date_stamp
        )
SELECT object_name
       , counter_name
       , instance_name
       , cntr_value
       , GETDATE()
FROM sys.dm_os_performance_counters
WHERE [object_name] LIKE '%Buffer Manager%'

WAITFOR DELAY '00:00:01';
GO 5
--------------------------------------------

--ADD CODE TO DROP THE CLEAN BUFFERS HERE

-------------------------------------------
DECLARE @getdate DATETIME;

SELECT @getdate = GETDATE();

INSERT INTO #dm_os_performance_counters
        (object_name
       , counter_name
       , instance_name
       , cntr_value
       , date_stamp
        )
SELECT object_name
       , counter_name
       , instance_name
       , cntr_value
       , GETDATE()
FROM sys.dm_os_performance_counters
WHERE [object_name] LIKE '%Buffer Manager%'

WAITFOR DELAY '00:00:01';
GO 5
--------------------------------------------


DECLARE @start DATETIME, @end DATETIME
SELECT @start = DATEADD(hh,-1,GETDATE())
SELECT @end = GETDATE()


----------------------------------------------------------
-- Show Buffer cache hit ratio for period of collection:
----------------------------------------------------------
SELECT (Hits.[cntr_value] * 1.0 / Total.[cntr_value]) * 100.0 AS [buffer_cache_hit_ratio] , Hits.[date_stamp]
FROM
(
SELECT [cntr_value], [date_stamp]
FROM #dm_os_performance_counters
WHERE [counter_name] = 'Buffer cache hit ratio'
	AND [date_stamp] BETWEEN @start AND @end
) Hits

INNER JOIN

(
SELECT [cntr_value], [date_stamp]
FROM #dm_os_performance_counters
WHERE [counter_name] = 'Buffer cache hit ratio base'
	AND [date_stamp] BETWEEN @start AND @end
) Total
ON Hits.[date_stamp] = Total.[date_stamp]
ORDER BY Hits.[date_stamp] DESC;


----------------------------------------------------------
-- Show Page life expectancy for period of collection:
----------------------------------------------------------
IF NOT EXISTS (SELECT name FROM tempdb.sys.tables WHERE name LIKE '%#dm_os_performance_counters%')
	BEGIN
		CREATE TABLE #dm_os_performance_counters
			(
				[object_name] [nvarchar](128) NULL,
				[counter_name] [nvarchar](128) NULL,
				[instance_name] [nvarchar](128) NULL,
				[cntr_value] [bigint] NULL,
				[date_stamp] [datetime] NULL
			) 
	END

SELECT [cntr_value], [date_stamp]
FROM #dm_os_performance_counters
WHERE [counter_name] = 'Page life expectancy'
	AND [date_stamp] BETWEEN @start AND @end
ORDER BY date_stamp DESC;

	
DROP TABLE #dm_os_performance_counters

/* PART 1: http://www.mssqltips.com/sqlservertip/2042/sql-server-performance-counter-dmv-sysdmosperformancecounters */ 
/* PART 2: http://www.mssqltips.com/sqlservertip/2072/collecting-sql-server-performance-counter-data-for-trending */
/* PART 3: http://www.mssqltips.com/sqlservertip/2194/trending-buffer-pool-performance-using-dmv-sysdmosperformancecounters */

GO


--=============================================
-- TEACH THE BUFFER POOL WHO'S BOSS
--=============================================
EXEC sys.sp_configure N'show advanced options', N'1'  RECONFIGURE WITH OVERRIDE
GO
EXEC sys.sp_configure N'max server memory (MB)', N'512'
GO
RECONFIGURE WITH OVERRIDE
GO
EXEC sys.sp_configure N'show advanced options', N'0'  RECONFIGURE WITH OVERRIDE
GO