--========================================================
--CREATE iDBA DATABASE IF IT DOESN'T EXIST
--========================================================
IF NOT EXISTS (SELECT name from sys.databases WHERE name = 'iDBA')
	BEGIN
		CREATE DATABASE [iDBA] ON  PRIMARY 
			(
				NAME = N'iDBA',
				FILENAME = N'<physical_file_data_location,,D:\Data\iDBA.mdf>' , 
		--		FILENAME = @filename_data, 
				SIZE = 128MB , 
				FILEGROWTH = 
				128MB
			)
		 LOG ON 
			(
				NAME = N'iDBA_log',
				FILENAME = N'<physical_file_log_location,,L:\Logs\iDBA_log.LDF>' , 
		--		FILENAME = @filename_log, 
				SIZE = 128MB , 
				FILEGROWTH = 128MB
			);

		ALTER DATABASE [iDBA] SET RECOVERY SIMPLE;
		EXEC iDBA.sys.sp_changedbowner 'sa', false;
	END
GO





--========================================================
--CREATE STORED PROC TO CAPTURE CPU INFO FROM RING BUFFER
--========================================================
USE iDBA;
GO

IF EXISTS (SELECT name FROM sys.procedures WHERE name = 'usp_collect_cpu_utilization_2008' AND OBJECT_SCHEMA_NAME(object_id) = 'dbo')
	BEGIN
		DROP PROCEDURE dbo.usp_collect_cpu_utilization_2008
	END
GO

CREATE PROCEDURE [dbo].usp_collect_cpu_utilization_2008 AS
SET QUOTED_IDENTIFIER ON;

DECLARE @now datetime;
DECLARE @ts_now bigint;

SET @now = GETDATE(); 
SET @ts_now  = (SELECT cpu_ticks/(cpu_ticks/ms_ticks)FROM sys.dm_os_sys_info); 

IF NOT EXISTS (SELECT name FROM [iDBA].sys.[tables] t WHERE name = 'cpu_utilization' AND OBJECT_SCHEMA_NAME(object_id) = 'dbo')
	BEGIN
		CREATE TABLE iDBA.[dbo].cpu_utilization (record_id int, sql_cpu_util tinyint,system_idle_process tinyint,other_process_cpu_util tinyint, record_time datetime)
		CREATE CLUSTERED INDEX CIX_cpu_utilization ON iDBA.[dbo].cpu_utilization(record_time)
		CREATE NONCLUSTERED INDEX NIX_cpu_utilization ON iDBA.[dbo].cpu_utilization(sql_cpu_util) INCLUDE (system_idle_process, other_process_cpu_util)
	END


INSERT INTO iDBA.dbo.cpu_utilization(record_id, sql_cpu_util, system_idle_process, other_process_cpu_util, record_time)
SELECT TOP(4*60) --This persists every 1 minute data point.  There is a limit of 96 data points returned hence need to run every 4 hours.
	record_id,
	SQLProcessUtilization AS [sql_cpu_util], 
	SystemIdle AS [system_idle_process], 
	100 - SystemIdle - SQLProcessUtilization AS [other_process_cpu_util], 
	DATEADD(ms, -1 * (@ts_now - [timestamp]), GETDATE()) AS [record_time] 
FROM ( 
	  SELECT record.value('(./Record/@id)[1]', 'int') AS record_id, 
			record.value('(./Record/SchedulerMonitorEvent/SystemHealth/SystemIdle)[1]', 'int') 
			AS [SystemIdle], 
			record.value('(./Record/SchedulerMonitorEvent/SystemHealth/ProcessUtilization)[1]', 
			'int') 
			AS [SQLProcessUtilization], [timestamp] 
	  FROM ( 
			SELECT [timestamp], CONVERT(xml, record) AS [record] 
			FROM sys.dm_os_ring_buffers 
			WHERE ring_buffer_type = N'RING_BUFFER_SCHEDULER_MONITOR' 
			AND record LIKE '%<SystemHealth>%') AS x 
	  ) AS y 
ORDER BY record_id DESC;

DELETE FROM iDBA.dbo.cpu_utilization WHERE record_time < DATEADD(d,-45, @now);
GO






----------------------------------------------------
--CREATE CPU UTILIZATION COLLECTION JOB
----------------------------------------------------
USE [msdb]
GO

IF EXISTS (SELECT name FROM msdb..sysjobs WHERE name = 'DBA_metadata_CPU_Utilization')
	BEGIN
		EXEC dbo.sp_delete_job @job_name = 'DBA_metadata_CPU_Utilization'
		    , @delete_history = 1
		   , @delete_unused_schedule = 1
		
	END
GO

DECLARE @job_command varchar(500)

SELECT @job_command = 'EXEC [dbo].usp_collect_cpu_utilization_2008;'


BEGIN TRANSACTION
DECLARE @ReturnCode INT
SELECT @ReturnCode = 0

IF NOT EXISTS (SELECT name FROM msdb.dbo.syscategories WHERE name=N'Administrative Job: Custom' AND category_class=1)
BEGIN
EXEC @ReturnCode = msdb.dbo.sp_add_category @class=N'JOB', @type=N'LOCAL', @name=N'Administrative Job: Custom'
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback

END

DECLARE @jobId BINARY(16)
EXEC @ReturnCode =  msdb.dbo.sp_add_job @job_name=N'DBA_metadata_CPU_Utilization', 
		@enabled=1, 
		@notify_level_eventlog=0, 
		@notify_level_email=0, 
		@notify_level_netsend=0, 
		@notify_level_page=0, 
		@delete_level=0, 
		@description=N'Collects previous 4 hours data for cpu utilization from sys.dm_os_ring_buffers and loads to iDBA database table for persisiting.  Stores 45 days of information before purging.', 
		@category_name=N'Administrative Job: Custom', 
		@owner_login_name=N'sa', @job_id = @jobId OUTPUT
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback

EXEC @ReturnCode = msdb.dbo.sp_add_jobstep @job_id=@jobId, @step_name=N'Collect Metadata', 
		@step_id=1, 
		@cmdexec_success_code=0, 
		@on_success_action=1, 
		@on_success_step_id=0, 
		@on_fail_action=2, 
		@on_fail_step_id=0, 
		@retry_attempts=0, 
		@retry_interval=0, 
		@os_run_priority=0, @subsystem=N'TSQL', 
		@command = @job_command, 
		@database_name=N'iDBA', 
		@flags=0
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback
EXEC @ReturnCode = msdb.dbo.sp_update_job @job_id = @jobId, @start_step_id = 1
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback
EXEC @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id=@jobId, @name=N'cpu_utilization_collection', 
		@enabled=1, 
		@freq_type=4, 
		@freq_interval=1, 
		@freq_subday_type=8, 
		@freq_subday_interval=4, 
		@freq_relative_interval=0, 
		@freq_recurrence_factor=0, 
		@active_start_date=20130826, 
		@active_end_date=99991231, 
		@active_start_time=1, 
		@active_end_time=235959
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback
EXEC @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @jobId, @server_name = N'(local)'
IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback
COMMIT TRANSACTION
GOTO EndSave
QuitWithRollback:
    IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION
EndSave:

GO