
--======================
--Average SQL CPU For Last 72 hours
--======================
SELECT 'Average SQL CPU For Last 72 hours', (AVG(sql_cpu_util)) AS average_sql_cpu_use
FROM iDBA.dbo.[cpu_utilization]
WHERE record_time > dateadd(hh, -48, getdate())


--======================
--Average Total CPU For Last 72 hours
--======================
SELECT 'Average Total CPU For Last 72 hours', 100-(AVG(system_idle_process)) AS average_total_cpu_use
FROM iDBA.dbo.[cpu_utilization]
WHERE record_time > dateadd(hh, -48, getdate())

--======================
--Highest 1 SQL CPU For Last 48 hours
--======================
SELECT TOP 1 'Highest SQL CPU Last 48hr:', [sql_cpu_util], record_time
FROM iDBA.dbo.[cpu_utilization]
WHERE record_time > dateadd(hh, -48, getdate())
ORDER BY sql_cpu_util DESC;


--======================
--Highest 1 Total CPU For Last 48 hours
--======================
SELECT TOP 1 'Highest Total CPU Last 48hr:', [other_process_cpu_util]+[sql_cpu_util] AS total_cpu, record_time
FROM iDBA.dbo.[cpu_utilization]
WHERE record_time > dateadd(hh, -48, getdate())
ORDER BY 2 DESC;



--========================
-- Putting it all together
--========================
SELECT (AVG(X.sql_cpu_util)) AS [Average SQL CPU For Last 72 hours]
	, 100-(AVG(X.system_idle_process)) AS [Average Total CPU For Last 72 hours]
	, MAX(S_CPU.[sql_cpu_util]) AS [Highest SQL CPU Last 48hr], CONVERT(VARCHAR(30),MAX(S_CPU.record_time), 120) AS [Time of Highest SQL CPU Last 48hr]
	, MAX(T_CPU.total_cpu) AS [Highest Total CPU Last 48h]
	, CONVERT(VARCHAR(30), MAX(T_CPU.record_time), 120) AS [Time of Highest Total CPU Last 48h]
FROM iDBA.dbo.[cpu_utilization] X
	CROSS JOIN
		(
			SELECT TOP 1 [sql_cpu_util], record_time
			FROM iDBA.dbo.[cpu_utilization]
			WHERE record_time > dateadd(hh, -48, getdate())
			ORDER BY sql_cpu_util DESC
		) AS S_CPU 

	CROSS JOIN
		(
			SELECT TOP 1 [other_process_cpu_util]+[sql_cpu_util] AS total_cpu, record_time
			FROM iDBA.dbo.[cpu_utilization]
			WHERE record_time > dateadd(hh, -48, getdate())
			ORDER BY 1 DESC
		) AS T_CPU 
WHERE X.record_time > dateadd(hh, -48, getdate())
